ICLUST.sort(ic.load, cut = 0, labels = NULL,loading=TRUE)A stable cluster solution will be one in which the output of these cluster definitions does not vary when clusters are formed from the clusters so defined.
ICLUST.graph,ICLUST.cluster, cluster.fit, VSS, factor2cluster