Another useful test for the number of factors is when the eigen values of a random matrix are greater than the eigen values of a a real matrix. Here we show VSS solutions to random data. A better test is probably fa.parallel.
VSS.parallel(ncases, nvariables,scree=FALSE,rotate="none")
| ncases | Number of simulated cases |
|---|---|
| nvariables | number of simulated variables |
| scree | Show a scree plot for random data -- see |
| rotate | rotate="none" or rotate="varimax" |
VSS like output to be plotted by VSS.plot
Very Simple Structure (VSS)
fa.parallel, VSS.plot, ICLUST, omega
#VSS.plot(VSS.parallel(200,24))